@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2018 Damon Lynch <damonlynch@gmail.com>
+# Copyright (C) 2017-2019 Damon Lynch <damonlynch@gmail.com>
 
 # This file is part of Rapid Photo Downloader.
 #
@@ -22,7 +22,7 @@ to download them.
 """
 
 __author__ = 'Damon Lynch'
-__copyright__ = "Copyright 2017-2018, Damon Lynch"
+__copyright__ = "Copyright 2017-2019, Damon Lynch"
 
 import logging
 from collections import namedtuple
@@ -134,6 +134,7 @@ class NewVersion(QObject):
                 else:
                     stable = self.version['stable']
                     dev = self.version['dev']
+                    # Dates in format 2019-08-10T08:01:00+00:00
                     dev_version = version_details(
                         version=pkg_resources.parse_version(dev['version']),
                         release_date=arrow.get(dev['date']).to('local'),
@@ -156,7 +157,8 @@ class NewVersion(QObject):
                 self.installed_via_pip = self.installedUsingPip()
             except Exception:
                 logging.debug(
-                    "Exception encountered when checking if pip was used to install"
+                    "Exception encountered when checking if pip was used to install "
+                    "(probably the program has not been installed)"
                 )
                 self.installed_via_pip = False
 
